@@ -33,6 +33,7 @@
 #include <libgnome/libgnome.h>
 #include <libgnomeui/gnome-ui-init.h>
 /* ---------------------------------- */
+#include <libgnomeui/gnome-thumbnail.h>
 
 static AppearanceData *
 init_appearance_data (int *argc, char ***argv)
@@ -60,6 +61,7 @@ init_appearance_data (int *argc, char ***argv)
     data = g_new (AppearanceData, 1);
     data->client = gconf_client_get_default ();
     data->xml = ui;
+    data->thumb_factory = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
   }
 
   return data;
@@ -80,6 +82,7 @@ main_window_response (GtkWidget *widget,
     desktop_shutdown (data);
     font_shutdown (data);
 
+    g_object_unref (data->thumb_factory);
     g_object_unref (data->client);
     g_object_unref (data->xml);
   }
@@ -156,8 +159,8 @@ main (int argc, char **argv)
   capplet_set_icon (w, "gnome-settings-theme");
   gtk_widget_show_all (w);
 
-  g_signal_connect_after (G_OBJECT (w), "response",
-                          G_CALLBACK (main_window_response), data);
+  g_signal_connect_after (w, "response",
+                          (GCallback) main_window_response, data);
 
   /* default to background page if files were given on the command line */
   if (wallpaper_files && !install_filename && !start_page)
